<?php

namespace Drupal\video_toolbox\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * FOrm.
 */
class VideoGetUploaderForm extends FormBase {

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'video_getter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $uid = \Drupal::currentUser()->id();
    $form['video_name'] = [
      '#type' => 'textarea',
      '#title' => "Upload a video name",
      '#required' => TRUE,
    ];

    $form['key'] = [
      '#type' => 'textarea',
      '#title' => "Save this key",
      '#required' => TRUE,
    ];
    $form['file'] = [
      '#type' => 'file',
      '#tile' => 'upload video',
      '#upload_location' => 'public://video_saving/',
    ];

    $form['uid'] = [
      '#type' => 'hidden',
      '#value' => $uid,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $all_files = $this->getRequest()->files->get('files', []);
    if (!empty($all_files['file'])) {
      $file_upload = $all_files['file'];
      if ($file_upload->isValid()) {
        $form_state->setValue('file', $file_upload->getRealPath());
        return;
      }
    }

    $form_state->setErrorByName('file', $this->t('The file could not be uploaded.'));
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $videogetter = \Drupal::service('video.get_service');
    $type = $form_state->getValue('video_name');
    $video = $form_state->getValue('file');
    $validators = ['file_validate_extensions' => ['mp4']];
    if ($video) {
      $file = file_save_upload('file', $validators, FALSE, 0);
      $file->setPermanent();
      $file->save();
    }
    $key = $form_state->getValue('key');
    $user_id = $form_state->getValue('uid');
    $videogetter->saveVideo($type, $key, $user_id);
  }

}
